==> haskell-wai-middleware-static-0.8.2-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-GaoBq4ehCbxJfoW6bWucFh
key: wai-middleware-static-0.8.2-GaoBq4ehCbxJfoW6bWucFh
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: 19c52038861ce76add76940b28e804c2
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-GaoBq4ehCbxJfoW6bWucFh
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6 directory-1.3.3.0
    expiring-cache-map-0.0.6.1-BXK0UHCkE2W5cX0GoVWbCp filepath-1.4.2.1
    http-types-0.12.3-3Nd2h8pfDaM3STPvc3OlR8
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk mtl-2.2.2
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    wai-3.2.2.1-723Ard8ux6SEGyYoOZ1rVh
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.8.2-81-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-middleware-static
version: 0.8.2
id: wai-middleware-static-0.8.2-9TOu11Xwuhl2VvhXtnesW7
key: wai-middleware-static-0.8.2-9TOu11Xwuhl2VvhXtnesW7
license: BSD-3-Clause
copyright: (c) 2012-2014 Andrew Farmer
maintainer: Andrew Farmer <afarmer@ittc.ku.edu>
author: Andrew Farmer <afarmer@ittc.ku.edu>
stability: experimental
homepage: https://github.com/scotty-web/wai-middleware-static
synopsis: WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.
    .
    [WAI] <http://hackage.haskell.org/package/wai>
category: Web
abi: 9b55727ab45c7af4b2c3c070038e9497
exposed: True
exposed-modules:
    Network.Wai.Middleware.Static
import-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/wai-middleware-static-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/wai-middleware-static-0.8.2
hs-libraries: HSwai-middleware-static-0.8.2-9TOu11Xwuhl2VvhXtnesW7
depends:
    base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    cryptonite-0.26-CDY1m3syfqq9pANhaEyZh6 directory-1.3.3.0
    expiring-cache-map-0.0.6.1-JYL73GoJ9NU6Pu813AKKkl filepath-1.4.2.1
    http-types-0.12.3-4mvqCFA58Pd9Ot84cA11d5
    memory-0.14.18-2FfCNwP2nzn4wBPtrz4oOB
    mime-types-0.1.0.9-2hmZJ5CmRudCuwA0xwTABk mtl-2.2.2
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78 text-1.2.3.1 time-1.8.0.2
    wai-3.2.2.1-CQ54CFlyR3DJGjuiF7FXOI
haddock-interfaces: /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock
haddock-html: /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
